@@ -4,7 +4,7 @@ Main interface for rum service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_rum import (
         Client,
         CloudWatchRUMClient,
@@ -12,10 +12,8 @@ Usage::
         ListAppMonitorsPaginator,
     )
 
-    session = boto3.Session()
-
-    client: CloudWatchRUMClient = boto3.client("rum")
-    session_client: CloudWatchRUMClient = session.client("rum")
+    session = Session()
+    client: CloudWatchRUMClient = session.client("rum")
 
     get_app_monitor_data_paginator: GetAppMonitorDataPaginator = client.get_paginator("get_app_monitor_data")
     list_app_monitors_paginator: ListAppMonitorsPaginator = client.get_paginator("list_app_monitors")
